.. _processFunctions:


Process Functions
*****************

.. currentmodule:: wikidatasets.processFunctions


get_subclasses
--------------
.. autofunction:: wikidatasets.processFunctions.get_subclasses

query_wikidata_dump
-------------------
.. autofunction:: wikidatasets.processFunctions.query_wikidata_dump

build_dataset
-------------
.. autofunction:: wikidatasets.processFunctions.build_dataset
